@@ -1,7 +1,8 @@
-__version__ = '0.10.2'
+__version__ = "0.11.2"
 
 from .classes import DateAssistant  # noqa
 from .utils import (  # noqa
+    cast_datetime_to_str,
     cast_str_to_datetime,
     get_days_diff_between,
     get_months_diff_between,
